@@ -25,11 +25,14 @@ class Fireplan:
         for error in self.validator.errors:
             logger.warning(f"Fehler in den Alarmdaten, '{error}' ist falsch formatiert und wird daher auf \"\" gesetzt!")
             data[error] = ""
+        logger.debug(data)
         r = requests.post(url, json=data, headers=self.headers)
         if r.text == "200":
             logger.info("Alarm erfolgreich gesendet")
         else:
             logger.error("Fehler beim senden des Alarms")
+            logger.error(f"Status code: {r.status_code}")
+            logger.error(f"Error text: {r.text}")
         return r.text == "200"
 
     def status(self, data):
@@ -43,10 +46,12 @@ class Fireplan:
         if self.validator.errors:
             logger.error(f"Status übermittlung auf Grund fehlerhafter daten abgebrochen!")
             return
+        logger.debug(data)
         r = requests.put(url, json=data, headers=self.headers)
         if r.text == "200":
             logger.info("Status erfolgreich gesendet")
         else:
             logger.error("Fehler beim senden des Status")
-            logger.error(r.text)
+            logger.error(f"Status code: {r.status_code}")
+            logger.error(f"Error text: {r.text}")
         return r.text == "200"
